@@ -7,9 +7,9 @@ import abc
 
 import sqlalchemy as sa
 import sqlalchemy.event
-import sqlalchemy.ext.declarative
 from six import add_metaclass
 from sqlalchemy import Column, ForeignKey, Integer, UnicodeText
+from sqlalchemy.ext.declarative import declared_attr
 from sqlalchemy.orm import backref, relationship
 
 from abilian.core.entities import Entity
@@ -17,7 +17,7 @@ from abilian.core.entities import Entity
 from .blob import Blob
 
 #: name of backref on target :class:`Entity` object
-ATTRIBUTE = '__attachments__'
+ATTRIBUTE = "__attachments__"
 
 
 @add_metaclass(abc.ABCMeta)
@@ -37,9 +37,7 @@ def register(cls):
           ....
     """
     if not issubclass(cls, Entity):
-        raise ValueError(
-            'Class must be a subclass of abilian.core.entities.Entity',
-        )
+        raise ValueError("Class must be a subclass of abilian.core.entities.Entity")
 
     SupportAttachment.register(cls)
     return cls
@@ -73,9 +71,10 @@ def for_entity(obj, check_support_attachments=False):
 
 class Attachment(Entity):
     """An Attachment owned by an :class:`Entity`."""
-    __auditable_entity__ = ('entity', 'attachment', ('id', 'name'))
 
-    @sa.ext.declarative.declared_attr
+    __auditable_entity__ = ("entity", "attachment", ("id", "name"))
+
+    @declared_attr
     def __mapper_args__(cls):
         # we cannot use super(Attachment, cls): declared_attr happens during
         # class construction. super(cls, cls) could work; as long as `cls`
@@ -83,8 +82,8 @@ class Attachment(Entity):
         # an infinite loop.
         #
         # Entity.__mapper_args__ calls the descriptor with 'Entity', not `cls`.
-        args = Entity.__dict__['__mapper_args__'].fget(cls)
-        args['order_by'] = cls.created_at
+        args = Entity.__dict__["__mapper_args__"].fget(cls)
+        args["order_by"] = cls.created_at
         return args
 
     entity_id = Column(Integer, ForeignKey(Entity.id), nullable=False)
@@ -92,37 +91,33 @@ class Attachment(Entity):
     #: owning entity
     entity = relationship(
         Entity,
-        lazy='immediate',
+        lazy="immediate",
         foreign_keys=[entity_id],
         backref=backref(
             ATTRIBUTE,
-            lazy='select',
-            order_by='Attachment.created_at',
+            lazy="select",
+            order_by="Attachment.created_at",
             cascade="all, delete-orphan",
         ),
     )
 
     blob_id = Column(Integer, sa.ForeignKey(Blob.id), nullable=False)
     #: file. Stored in a :class:`Blob`
-    blob = relationship(Blob, cascade='all, delete', foreign_keys=[blob_id])
+    blob = relationship(Blob, cascade="all, delete", foreign_keys=[blob_id])
 
-    description = Column(
-        UnicodeText(),
-        nullable=False,
-        default='',
-        server_default='',
-    )
+    description = Column(UnicodeText(), nullable=False, default="", server_default="")
 
     def __repr__(self):
         class_ = self.__class__
         mod_ = class_.__module__
         classname = class_.__name__
-        return '<{}.{} instance at 0x{:x} entity id={!r}>' \
-            .format(mod_, classname, id(self), self.entity_id)
+        return "<{}.{} instance at 0x{:x} entity id={!r}>".format(
+            mod_, classname, id(self), self.entity_id
+        )
 
 
-@sa.event.listens_for(Attachment, 'before_insert', propagate=True)
-@sa.event.listens_for(Attachment, 'before_update', propagate=True)
+@sa.event.listens_for(Attachment, "before_insert", propagate=True)
+@sa.event.listens_for(Attachment, "before_update", propagate=True)
 def set_attachment_name(mapper, connection, target):
     if target.name:
         return
@@ -131,6 +126,6 @@ def set_attachment_name(mapper, connection, target):
     if not blob:
         return
 
-    filename = blob.meta.get('filename')
+    filename = blob.meta.get("filename")
     if filename is not None:
         target.name = filename
