@@ -10,7 +10,6 @@ from six import text_type
 
 
 class Sentry(RavenExt):
-
     def init_app(self, app, *args, **kwargs):
         super(Sentry, self).init_app(app, *args, **kwargs)
         user_logged_in.connect(self._on_user_logged_in, sender=app)
@@ -20,13 +19,13 @@ class Sentry(RavenExt):
 
     @property
     def raven_js_url(self):
-        url = '//cdn.ravenjs.com/{version}/raven.min.js'
+        url = "//cdn.ravenjs.com/{version}/raven.min.js"
         cfg = current_app.config
-        version = text_type(cfg['SENTRY_JS_VERSION'])
-        plugins = cfg.get('SENTRY_JS_PLUGINS', [])
+        version = text_type(cfg["SENTRY_JS_VERSION"])
+        plugins = cfg.get("SENTRY_JS_PLUGINS", [])
         if plugins:
-            version = version + '/' + ','.join(plugins)
+            version = version + "/" + ",".join(plugins)
         return url.format(version=version)
 
 
-__all__ = ['Sentry']
+__all__ = ["Sentry"]
