@@ -58,16 +58,16 @@ class SQLAlchemy(SAExtension):
     def apply_driver_hacks(self, app, info, options):
         SAExtension.apply_driver_hacks(self, app, info, options)
 
-        if info.drivername == 'sqlite':
-            connect_args = options.setdefault('connect_args', {})
+        if info.drivername == "sqlite":
+            connect_args = options.setdefault("connect_args", {})
 
-            if 'isolation_level' not in connect_args:
+            if "isolation_level" not in connect_args:
                 # required to support savepoints/rollback without error. It disables
                 # implicit BEGIN/COMMIT statements made by pysqlite (a COMMIT kills all
                 # savepoints made).
-                connect_args['isolation_level'] = None
-        elif info.drivername.startswith('postgres'):
-            options.setdefault('client_encoding', 'utf8')
+                connect_args["isolation_level"] = None
+        elif info.drivername.startswith("postgres"):
+            options.setdefault("client_encoding", "utf8")
 
 
 # PATCH flask_sqlalchemy for proper info in debug toolbar.
@@ -78,21 +78,24 @@ class SQLAlchemy(SAExtension):
 def _calling_context(app_path):
     frm = sys._getframe(1)
     entered_sa_code = exited_sa_code = False
-    sa_caller = '<unknown>'
+    sa_caller = "<unknown>"
     format_name = (
-        '{frm.f_code.co_filename}:{frm.f_lineno} '
-        '({frm.f_code.co_name})'.format
+        "{frm.f_code.co_filename}:{frm.f_lineno} " "({frm.f_code.co_name})".format
     )
 
     while frm.f_back is not None:
-        name = frm.f_globals.get('__name__')
-        if name and (name == app_path or name.startswith(app_path + '.') or
-                     name.startswith('abilian.')):
+        name = frm.f_globals.get("__name__")
+        if name and (
+            name == app_path
+            or name.startswith(app_path + ".")
+            or name.startswith("abilian.")
+        ):
             return format_name(frm=frm)
 
         if not exited_sa_code:
-            in_sa_code = name and (name == 'sqlalchemy' or
-                                   name.startswith('sqlalchemy.'))
+            in_sa_code = name and (
+                name == "sqlalchemy" or name.startswith("sqlalchemy.")
+            )
             if not entered_sa_code:
                 entered_sa_code = in_sa_code
             elif not in_sa_code:
@@ -119,9 +122,9 @@ def filter_cols(model, *filtered_columns):
     """
     m = sa.orm.class_mapper(model)
     return list(
-        {p.key
-         for p in m.iterate_properties
-         if hasattr(p, 'columns')}.difference(filtered_columns),
+        {p.key for p in m.iterate_properties if hasattr(p, "columns")}.difference(
+            filtered_columns
+        )
     )
 
 
@@ -200,7 +203,7 @@ class MutationList(Mutable, list):
     #  http://docs.sqlalchemy.org/en/rel_0_8/orm/extensions/mutable.html#supporting-pickling
     def __getstate__(self):
         d = self.__dict__.copy()
-        d.pop('_parents', None)
+        d.pop("_parents", None)
         return d
 
     # list methods
@@ -265,6 +268,7 @@ class JSON(sa.types.TypeDecorator):
 
     Usage JSON() Takes same parameters as sqlalchemy.types.Text
     """
+
     impl = sa.types.Text
 
     def process_bind_param(self, value, dialect):
@@ -307,7 +311,7 @@ def JSONList(*args, **kwargs):
     """
     type_ = JSON
     try:
-        if kwargs.pop('unique_sorted'):
+        if kwargs.pop("unique_sorted"):
             type_ = JSONUniqueListType
     except KeyError:
         pass
@@ -323,10 +327,11 @@ class UUID(sa.types.TypeDecorator):
 
     From SQLAlchemy documentation.
     """
+
     impl = sa.types.CHAR
 
     def load_dialect_impl(self, dialect):
-        if dialect.name == 'postgresql':
+        if dialect.name == "postgresql":
             return dialect.type_descriptor(sa.dialects.postgresql.UUID())
         else:
             return dialect.type_descriptor(sa.types.CHAR(32))
@@ -334,7 +339,7 @@ class UUID(sa.types.TypeDecorator):
     def process_bind_param(self, value, dialect):
         if value is None:
             return value
-        elif dialect.name == 'postgresql':
+        elif dialect.name == "postgresql":
             return str(value)
         else:
             if not isinstance(value, uuid.UUID):
@@ -346,7 +351,7 @@ class UUID(sa.types.TypeDecorator):
         return value if value is None else uuid.UUID(value)
 
     def compare_against_backend(self, dialect, conn_type):
-        if dialect.name == 'postgresql':
+        if dialect.name == "postgresql":
             return isinstance(conn_type, sa.dialects.postgresql.UUID)
         else:
             return isinstance(conn_type, sa.types.CHAR)
@@ -354,6 +359,7 @@ class UUID(sa.types.TypeDecorator):
 
 class Locale(sa.types.TypeDecorator):
     """Store a :class:`babel.Locale` instance."""
+
     impl = sa.types.UnicodeText
 
     @property
@@ -366,19 +372,16 @@ class Locale(sa.types.TypeDecorator):
 
         if not isinstance(value, babel.Locale):
             if not isinstance(value, string_types):
-                raise ValueError(
-                    "Unknown locale value: " +
-                    format(
-                        repr(value)))
+                raise ValueError("Unknown locale value: " + format(repr(value)))
             if not value.strip():
                 return None
             value = babel.Locale.parse(value)
 
         code = text_type(value.language)
         if value.territory:
-            code += '_' + text_type(value.territory)
+            code += "_" + text_type(value.territory)
         elif value.script:
-            code += '_' + text_type(value.territory)
+            code += "_" + text_type(value.territory)
 
         return code
 
@@ -388,6 +391,7 @@ class Locale(sa.types.TypeDecorator):
 
 class Timezone(sa.types.TypeDecorator):
     """Store a :class:`pytz.tzfile.DstTzInfo` instance."""
+
     impl = sa.types.UnicodeText
 
     @property
@@ -419,4 +423,4 @@ class Timezone(sa.types.TypeDecorator):
 # Ref:
 # https://bitbucket.org/zzzeek/sqlalchemy/issues/3218/__module__-should-be-set-on-functions
 if not sa.orm.relationship.__module__:
-    sa.orm.relationship.__module__ = 'sqlalchemy.orm'
+    sa.orm.relationship.__module__ = "sqlalchemy.orm"
