@@ -12,8 +12,12 @@ TODO: rename Converter into ConversionService ?
 
 from __future__ import absolute_import
 
-from abilian.services.conversion.handlers import PdfToTextHandler, \
-    PdfToPpmHandler, ImageMagickHandler, LibreOfficePdfHandler
+from abilian.services.conversion.handlers import (
+    PdfToTextHandler,
+    PdfToPpmHandler,
+    ImageMagickHandler,
+    LibreOfficePdfHandler,
+)
 from .service import Converter, ConversionError, HandlerNotFound
 
 # Singleton, yuck!
@@ -26,11 +30,11 @@ converter.register_handler(LibreOfficePdfHandler())
 conversion_service = converter
 
 __all__ = (
-    'conversion_service',
-    'converter',
-    'Converter',
-    'ConversionError',
-    'HandlerNotFound',
+    "conversion_service",
+    "converter",
+    "Converter",
+    "ConversionError",
+    "HandlerNotFound",
 )
 
 # converter.register_handler(AbiwordPDFHandler())
