@@ -33,7 +33,8 @@ logger = logging.getLogger(__name__)
 
 # Quick check for tests
 def has_pdftotext():
-    dev_null = open('/dev/null', 'wb')
+    # type: () -> bool
+    dev_null = open("/dev/null", "wb")
     try:
         status = subprocess.call("pdftotext", stderr=dev_null)
         return status == 0
@@ -44,12 +45,11 @@ def has_pdftotext():
 
 
 def has_libreoffice():
-    dev_null = open('/dev/null', 'wb')
+    # type: () -> bool
+    dev_null = open("/dev/null", "wb")
     try:
         status = subprocess.call(
-            ["soffice", "--help"],
-            stdout=dev_null,
-            stderr=dev_null,
+            ["soffice", "--help"], stdout=dev_null, stderr=dev_null
         )
         return status == 0
     except BaseException:
@@ -99,7 +99,7 @@ class Handler(object):
                 break
 
         for pat in self.produces_mime_types:
-            if re.match("^%s$" % pat, target_mime_type):
+            if re.match("^{}$".format(pat), target_mime_type):
                 match_target = True
                 break
 
@@ -111,17 +111,17 @@ class Handler(object):
 
 
 class PdfToTextHandler(Handler):
-    accepts_mime_types = ['application/pdf', 'application/x-pdf']
-    produces_mime_types = ['text/plain']
+    accepts_mime_types = ["application/pdf", "application/x-pdf"]
+    produces_mime_types = ["text/plain"]
 
     def convert(self, blob, **kw):
         with make_temp_file(blob) as in_fn, make_temp_file() as out_fn:
             try:
-                subprocess.check_call(['pdftotext', in_fn, out_fn])
+                subprocess.check_call(["pdftotext", in_fn, out_fn])
             except Exception as e:
-                raise raise_from(ConversionError('pdftotext failed'), e)
+                raise raise_from(ConversionError("pdftotext failed"), e)
 
-            converted = open(out_fn, 'rb').read()
+            converted = open(out_fn, "rb").read()
             encoding = self.encoding_sniffer.from_file(out_fn)
 
         if encoding in ("binary", None):
@@ -136,24 +136,27 @@ class PdfToTextHandler(Handler):
 
 
 class AbiwordTextHandler(Handler):
-    accepts_mime_types = ['application/msword']
-    produces_mime_types = ['text/plain']
+    accepts_mime_types = ["application/msword"]
+    produces_mime_types = ["text/plain"]
 
     def convert(self, blob, **kw):
         tmp_dir = self.TMP_DIR
         cur_dir = os.getcwd()
-        with make_temp_file(blob, suffix=".doc") as in_fn,\
-                make_temp_file(suffix='.txt') as out_fn:
+        with make_temp_file(blob, suffix=".doc") as in_fn, make_temp_file(
+            suffix=".txt"
+        ) as out_fn:
             try:
                 os.chdir(str(tmp_dir))
-                subprocess.check_call([
-                    'abiword',
-                    '--to',
-                    os.path.basename(out_fn),
-                    os.path.basename(in_fn),
-                ])
+                subprocess.check_call(
+                    [
+                        "abiword",
+                        "--to",
+                        os.path.basename(out_fn),
+                        os.path.basename(in_fn),
+                    ]
+                )
             except Exception as e:
-                raise_from(ConversionError('abiword failed'), e)
+                raise_from(ConversionError("abiword failed"), e)
             finally:
                 os.chdir(cur_dir)
 
@@ -173,26 +176,29 @@ class AbiwordTextHandler(Handler):
 
 class AbiwordPDFHandler(Handler):
     accepts_mime_types = [
-        'application/msword',
-        'application/vnd.oasis.opendocument.text',
-        'text/rtf',
+        "application/msword",
+        "application/vnd.oasis.opendocument.text",
+        "text/rtf",
     ]
-    produces_mime_types = ['application/pdf']
+    produces_mime_types = ["application/pdf"]
 
     def convert(self, blob, **kw):
         cur_dir = os.getcwd()
-        with make_temp_file(blob, suffix=".doc") as in_fn,\
-                make_temp_file(suffix='.pdf') as out_fn:
+        with make_temp_file(blob, suffix=".doc") as in_fn, make_temp_file(
+            suffix=".pdf"
+        ) as out_fn:
             try:
                 os.chdir(bytes(self.TMP_DIR))
-                subprocess.check_call([
-                    'abiword',
-                    '--to',
-                    os.path.basename(out_fn),
-                    os.path.basename(in_fn),
-                ])
+                subprocess.check_call(
+                    [
+                        "abiword",
+                        "--to",
+                        os.path.basename(out_fn),
+                        os.path.basename(in_fn),
+                    ]
+                )
             except Exception as e:
-                raise_from(ConversionError('abiword failed'), e)
+                raise_from(ConversionError("abiword failed"), e)
             finally:
                 os.chdir(cur_dir)
 
@@ -201,44 +207,39 @@ class AbiwordPDFHandler(Handler):
 
 
 class ImageMagickHandler(Handler):
-    accepts_mime_types = ['image/.*']
-    produces_mime_types = ['application/pdf']
+    accepts_mime_types = ["image/.*"]
+    produces_mime_types = ["application/pdf"]
 
     def convert(self, blob, **kw):
         with make_temp_file(blob) as in_fn, make_temp_file() as out_fn:
             try:
-                subprocess.check_call(['convert', in_fn, "pdf:" + out_fn])
-                converted = open(out_fn, 'rb').read()
+                subprocess.check_call(["convert", in_fn, "pdf:" + out_fn])
+                converted = open(out_fn, "rb").read()
                 return converted
             except Exception as e:
-                raise_from(ConversionError('convert failed'), e)
+                raise_from(ConversionError("convert failed"), e)
 
 
 class PdfToPpmHandler(Handler):
-    accepts_mime_types = ['application/pdf', 'application/x-pdf']
-    produces_mime_types = ['image/jpeg']
+    accepts_mime_types = ["application/pdf", "application/x-pdf"]
+    produces_mime_types = ["image/jpeg"]
 
     def convert(self, blob, size=500):
         """Size is the maximum horizontal size."""
         l = []
         with make_temp_file(blob) as in_fn, make_temp_file() as out_fn:
             try:
-                subprocess.check_call(['pdftoppm', '-jpeg', in_fn, out_fn])
-                l = sorted(glob.glob("%s-*.jpg" % out_fn))
+                subprocess.check_call(["pdftoppm", "-jpeg", in_fn, out_fn])
+                l = sorted(glob.glob("{}-*.jpg".format(out_fn)))
 
                 converted_images = []
                 for fn in l:
-                    converted = resize(
-                        open(fn, 'rb').read(),
-                        size,
-                        size,
-                        mode=FIT,
-                    )
+                    converted = resize(open(fn, "rb").read(), size, size)
                     converted_images.append(converted)
 
                 return converted_images
             except Exception as e:
-                raise_from(ConversionError('pdftoppm failed'), e)
+                raise_from(ConversionError("pdftoppm failed"), e)
             finally:
                 for fn in l:
                     try:
@@ -255,24 +256,24 @@ class UnoconvPdfHandler(Handler):
 
     # TODO: add more if needed.
     accepts_mime_types = [
-        'application/vnd.oasis.*',
-        'application/msword',
-        'application/mspowerpoint',
-        'application/vnd.ms-powerpoint',
-        'application/vnd.ms-excel',
-        'application/vnd.ms-office',
-        'application/vnd.ms-word',
-        'application/ms-excel',
-        'application/vnd.openxmlformats-officedocument.*',
-        'text/rtf',
+        "application/vnd.oasis.*",
+        "application/msword",
+        "application/mspowerpoint",
+        "application/vnd.ms-powerpoint",
+        "application/vnd.ms-excel",
+        "application/vnd.ms-office",
+        "application/vnd.ms-word",
+        "application/ms-excel",
+        "application/vnd.openxmlformats-officedocument.*",
+        "text/rtf",
     ]
-    produces_mime_types = ['application/pdf']
+    produces_mime_types = ["application/pdf"]
     run_timeout = 60
     _process = None
-    unoconv = 'unoconv'
+    unoconv = "unoconv"
 
     def init_app(self, app):
-        unoconv = app.config.get('UNOCONV_LOCATION')
+        unoconv = app.config.get("UNOCONV_LOCATION")
         found = False
         execute_ok = False
 
@@ -286,33 +287,27 @@ class UnoconvPdfHandler(Handler):
                 execute_ok = os.access(unoconv, os.X_OK)
                 if not execute_ok:
                     self.log.warning(
-                        'Not allowed to execute "%s", fallback to "unoconv"',
-                        unoconv,
+                        'Not allowed to execute "%s", fallback to "unoconv"', unoconv
                     )
             else:
-                self.log.warning(
-                    'Cannot find "%s", fallback to "unoconv"',
-                    unoconv,
-                )
+                self.log.warning('Cannot find "%s", fallback to "unoconv"', unoconv)
 
         if not unoconv or not found or not execute_ok:
-            unoconv = 'unoconv'
+            unoconv = "unoconv"
 
         self.unoconv = unoconv
 
     @property
     def unoconv_version(self):
         # Hack for my Mac, FIXME later
-        if Path(
-            "/Applications/LibreOffice.app/Contents/program/python",
-        ).exists():
+        if Path("/Applications/LibreOffice.app/Contents/program/python").exists():
             cmd = [
-                '/Applications/LibreOffice.app/Contents/program/python',
-                '/usr/local/bin/unoconv',
-                '--version',
+                "/Applications/LibreOffice.app/Contents/program/python",
+                "/usr/local/bin/unoconv",
+                "--version",
             ]
         else:
-            cmd = [self.unoconv, '--version']
+            cmd = [self.unoconv, "--version"]
 
         process = subprocess.Popen(cmd, stdout=subprocess.PIPE)
         out, err = process.communicate()
@@ -321,17 +316,16 @@ class UnoconvPdfHandler(Handler):
     def convert(self, blob, **kw):
         """Convert using unoconv converter."""
         timeout = self.run_timeout
-        with make_temp_file(blob) as in_fn, \
-                make_temp_file(prefix='tmp-unoconv-', suffix=".pdf") as out_fn:
+        with make_temp_file(blob) as in_fn, make_temp_file(
+            prefix="tmp-unoconv-", suffix=".pdf"
+        ) as out_fn:
 
-            args = ['-f', 'pdf', '-o', out_fn, in_fn]
+            args = ["-f", "pdf", "-o", out_fn, in_fn]
             # Hack for my Mac, FIXME later
-            if Path(
-                "/Applications/LibreOffice.app/Contents/program/python",
-            ).exists():
+            if Path("/Applications/LibreOffice.app/Contents/program/python").exists():
                 cmd = [
-                    '/Applications/LibreOffice.app/Contents/program/python',
-                    '/usr/local/bin/unoconv',
+                    "/Applications/LibreOffice.app/Contents/program/python",
+                    "/usr/local/bin/unoconv",
                 ] + args
             else:
                 cmd = [self.unoconv] + args
@@ -339,14 +333,12 @@ class UnoconvPdfHandler(Handler):
             def run_uno():
                 try:
                     self._process = subprocess.Popen(
-                        cmd,
-                        close_fds=True,
-                        cwd=bytes(self.TMP_DIR),
+                        cmd, close_fds=True, cwd=bytes(self.TMP_DIR)
                     )
                     self._process.communicate()
                 except Exception as e:
-                    logger.error('run_uno error: %s', bytes(e), exc_info=True)
-                    raise_from(ConversionError('unoconv failed'), e)
+                    logger.error("run_uno error: %s", bytes(e), exc_info=True)
+                    raise_from(ConversionError("unoconv failed"), e)
 
             run_thread = threading.Thread(target=run_uno)
             run_thread.start()
@@ -360,15 +352,10 @@ class UnoconvPdfHandler(Handler):
                         try:
                             self._process.kill()
                         except OSError:
-                            logger.warning(
-                                "Failed to kill process %s",
-                                self._process,
-                            )
+                            logger.warning("Failed to kill process %s", self._process)
 
                     self._process = None
-                    raise ConversionError(
-                        "Conversion timeout ({})".format(timeout),
-                    )
+                    raise ConversionError("Conversion timeout ({})".format(timeout))
 
                 converted = open(out_fn).read()
                 return converted
@@ -384,23 +371,23 @@ class LibreOfficePdfHandler(Handler):
 
     # TODO: add more if needed.
     accepts_mime_types = [
-        'application/vnd.oasis.*',
-        'application/msword',
-        'application/mspowerpoint',
-        'application/vnd.ms-powerpoint',
-        'application/vnd.ms-excel',
-        'application/vnd.ms-office',
-        'application/ms-excel',
-        'application/vnd.openxmlformats-officedocument.*',
-        'text/rtf',
+        "application/vnd.oasis.*",
+        "application/msword",
+        "application/mspowerpoint",
+        "application/vnd.ms-powerpoint",
+        "application/vnd.ms-excel",
+        "application/vnd.ms-office",
+        "application/ms-excel",
+        "application/vnd.openxmlformats-officedocument.*",
+        "text/rtf",
     ]
-    produces_mime_types = ['application/pdf']
+    produces_mime_types = ["application/pdf"]
     run_timeout = 60
     _process = None
-    soffice = 'soffice'
+    soffice = "soffice"
 
     def init_app(self, app):
-        soffice = app.config.get('SOFFICE_LOCATION')
+        soffice = app.config.get("SOFFICE_LOCATION")
         found = False
         execute_ok = False
 
@@ -446,14 +433,12 @@ class LibreOfficePdfHandler(Handler):
             def run_soffice():
                 try:
                     self._process = subprocess.Popen(
-                        cmd,
-                        close_fds=True,
-                        cwd=bytes(self.TMP_DIR),
+                        cmd, close_fds=True, cwd=bytes(self.TMP_DIR)
                     )
                     self._process.communicate()
                 except Exception as e:
-                    logger.error('soffice error: %s', bytes(e), exc_info=True)
-                    raise_from(ConversionError('soffice conversion failed'), e)
+                    logger.error("soffice error: %s", bytes(e), exc_info=True)
+                    raise_from(ConversionError("soffice conversion failed"), e)
 
             run_thread = threading.Thread(target=run_soffice)
             run_thread.start()
@@ -467,18 +452,13 @@ class LibreOfficePdfHandler(Handler):
                         try:
                             self._process.kill()
                         except OSError:
-                            logger.warning(
-                                "Failed to kill process %s",
-                                self._process,
-                            )
+                            logger.warning("Failed to kill process %s", self._process)
 
                     self._process = None
-                    raise ConversionError(
-                        "Conversion timeout ({})".format(timeout),
-                    )
+                    raise ConversionError("Conversion timeout ({})".format(timeout))
 
                 out_fn = os.path.splitext(in_fn)[0] + ".pdf"
-                converted = open(out_fn, 'rb').read()
+                converted = open(out_fn, "rb").read()
                 return converted
             finally:
                 self._process = None
@@ -494,8 +474,8 @@ class CloudoooPdfHandler(Handler):
     FIXME: needs cleanup, or removal.
     """
 
-    accepts_mime_types = [r'application/.*']
-    produces_mime_types = ['application/pdf']
+    accepts_mime_types = [r"application/.*"]
+    produces_mime_types = ["application/pdf"]
 
     # Hardcoded for now
     SERVER_URL = "http://localhost:8011"
@@ -510,38 +490,38 @@ class CloudoooPdfHandler(Handler):
     }
 
     def convert(self, key):
-        in_fn = "data/%s.blob" % key
-        in_mime_type = open("data/%s.mime" % key).read()
+        in_fn = "data/{}.blob".format(key)
+        in_mime_type = open("data/{}.mime".format(key)).read()
         file_extension = mimetypes.guess_extension(in_mime_type).strip(".")
 
         data = encodestring(open(in_fn).read())
         proxy = ServerProxy(self.SERVER_URL, allow_none=True)
 
         if in_mime_type.startswith("application/vnd.oasis.opendocument"):
-            data = proxy.convertFile(data, file_extension, 'pdf')
+            data = proxy.convertFile(data, file_extension, "pdf")
         else:
             pivot_format = self.pivot_format_map[file_extension]
             data = proxy.convertFile(data, file_extension, pivot_format)
-            data = proxy.convertFile(data, pivot_format, 'pdf')
+            data = proxy.convertFile(data, pivot_format, "pdf")
 
         converted = decodestring(data)
         new_key = hashlib.md5(converted).hexdigest()
-        with open("data/%s.blob" % new_key, "wb") as fd:
+        with open("data/{}.blob".format(new_key), "wb") as fd:
             fd.write(converted)
         return new_key
 
 
 class WvwareTextHandler(Handler):
-    accepts_mime_types = ['application/msword']
-    produces_mime_types = ['text/plain']
+    accepts_mime_types = ["application/msword"]
+    produces_mime_types = ["text/plain"]
 
     def convert(self, blob, **kw):
 
         with make_temp_file(blob) as in_fn, make_temp_file() as out_fn:
             try:
-                subprocess.check_call(['wvText', in_fn, out_fn])
+                subprocess.check_call(["wvText", in_fn, out_fn])
             except Exception as e:
-                raise_from(ConversionError('wxText failed'), e)
+                raise_from(ConversionError("wxText failed"), e)
 
             converted = open(out_fn).read()
 
@@ -549,11 +529,7 @@ class WvwareTextHandler(Handler):
             if encoding in ("binary", None):
                 encoding = "ascii"
             try:
-                converted_unicode = text_type(
-                    converted,
-                    encoding,
-                    errors="ignore",
-                )
+                converted_unicode = text_type(converted, encoding, errors="ignore")
             except BaseException:
                 traceback.print_exc()
                 converted_unicode = text_type(converted, errors="ignore")
