@@ -1,5 +1,6 @@
 # coding=utf-8
-from __future__ import absolute_import, print_function, unicode_literals
+from __future__ import absolute_import, division, print_function, \
+    unicode_literals
 
 from pathlib import Path
 
@@ -11,24 +12,24 @@ from .. import CROP, FIT, SCALE, get_save_format, get_size, resize
 @fixture
 def orig_image():
     # 725x518
-    return (Path(__file__).parent / "cat.jpg").open('rb').read()
+    return (Path(__file__).parent / "cat.jpg").open("rb").read()
 
 
 def test_get_save_format():
-    assert get_save_format('JPG') == 'JPEG'
-    assert get_save_format('JPEG') == 'JPEG'
-    assert get_save_format('PNG') == 'PNG'
-    assert get_save_format('GIF') == 'PNG'
-    assert get_save_format('unknown') == 'JPEG'
+    assert get_save_format("JPG") == "JPEG"
+    assert get_save_format("JPEG") == "JPEG"
+    assert get_save_format("PNG") == "PNG"
+    assert get_save_format("GIF") == "PNG"
+    assert get_save_format("unknown") == "JPEG"
 
 
 def test_fit(orig_image):
-    image = resize(orig_image, 500, 500, FIT)
+    image = resize(orig_image, 500, 500)
     x, y = get_size(image)
     assert (x, y) == (500, 357)
 
     # image already fits in desired dimension
-    image = resize(orig_image, 1000, 1000, FIT)
+    image = resize(orig_image, 1000, 1000)
     x, y = get_size(image)
     assert x == 725 and y == 518
 
