@@ -11,13 +11,13 @@ from abilian.core.entities import Entity
 
 class IndexedContact(Entity):
     # default is 'test_service.IndexedContact'
-    entity_type = 'abilian.services.indexing.IndexedContact'
+    entity_type = "abilian.services.indexing.IndexedContact"
     name = sa.Column(sa.UnicodeText)
 
 
 @fixture
 def svc(app):
-    svc = app.services['indexing']
+    svc = app.services["indexing"]
     with app.app_context():
         svc.start()
         yield svc
@@ -31,7 +31,7 @@ def test_app_state(app, svc):
 
 
 def test_index_only_after_final_commit(app, session, svc):
-    contact = IndexedContact(name='John Doe')
+    contact = IndexedContact(name="John Doe")
 
     state = svc.app_state
 
@@ -41,11 +41,11 @@ def test_index_only_after_final_commit(app, session, svc):
     session.add(contact)
     # no commit: model is in wait queue
     session.flush()
-    assert state.to_update == [('new', contact)]
+    assert state.to_update == [("new", contact)]
 
     # commit but in a sub transaction: model still in wait queue
     session.commit()
-    assert state.to_update == [('new', contact)]
+    assert state.to_update == [("new", contact)]
 
     # 'final' commit: models sent for indexing update
     session.commit()
