@@ -4,4 +4,4 @@ from __future__ import absolute_import, division, print_function
 
 from .service import repository, session_repository
 
-__all__ = ['repository', 'session_repository']
+__all__ = ["repository", "session_repository"]
