@@ -11,7 +11,7 @@ from uuid import UUID, uuid1
 
 import sqlalchemy as sa
 import sqlalchemy.event
-from flask import _app_ctx_stack, current_app
+from flask import _app_ctx_stack
 from flask.globals import _lookup_app_object
 from six import text_type
 from sqlalchemy.orm.session import Session
@@ -24,7 +24,7 @@ _NULL_MARK = object()
 
 def _assert_uuid(uuid):
     if not isinstance(uuid, UUID):
-        raise ValueError('Not an uuid.UUID instance', uuid)
+        raise ValueError("Not an uuid.UUID instance", uuid)
 
 
 class RepositoryServiceState(ServiceState):
@@ -34,13 +34,14 @@ class RepositoryServiceState(ServiceState):
 
 class RepositoryService(Service):
     """Service for storage of binary objects referenced in database."""
-    name = 'repository'
+
+    name = "repository"
     AppStateClass = RepositoryServiceState
 
     def init_app(self, app):
         Service.init_app(self, app)
 
-        path = app.DATA_DIR / 'files'
+        path = app.DATA_DIR / "files"
         if not path.exists():
             path.mkdir(mode=0o775, parents=True)
 
@@ -72,7 +73,7 @@ class RepositoryService(Service):
         return dest
 
     def get(self, uuid, default=None):
-        # type: (UUID, Any) -> Path
+        # type: (UUID, Optional[Path]) -> Optional[Path]
         """Return absolute :class:`Path` object for given uuid, if this uuid
         exists in repository, or `default` if it doesn't.
 
@@ -83,8 +84,8 @@ class RepositoryService(Service):
             return default
         return path
 
-    def set(self, uuid, content, encoding='utf-8'):
-        # type: (UUID, Any, Text) -> None
+    def set(self, uuid, content, encoding="utf-8"):
+        # type: (UUID, Any, Optional[Text]) -> None
         """Store binary content with uuid as key.
 
         :param:uuid: :class:`UUID` instance
@@ -95,12 +96,12 @@ class RepositoryService(Service):
         if not dest.parent.exists():
             dest.parent.mkdir(0o775, parents=True)
 
-        if hasattr(content, 'read'):
+        if hasattr(content, "read"):
             content = content.read()
 
-        mode = 'tw'
+        mode = "tw"
         if not isinstance(content, text_type):
-            mode = 'bw'
+            mode = "bw"
             encoding = None
 
         with dest.open(mode, encoding=encoding) as f:
@@ -115,15 +116,15 @@ class RepositoryService(Service):
         """
         dest = self.abs_path(uuid)
         if not dest.exists():
-            raise KeyError('No file can be found for this uuid', uuid)
+            raise KeyError("No file can be found for this uuid", uuid)
 
         dest.unlink()
 
     def __getitem__(self, uuid):
         # type: (UUID) -> Any
-        value = self.get(uuid, default=_NULL_MARK)
-        if value is _NULL_MARK:
-            raise KeyError('No file can be found for this uuid', uuid)
+        value = self.get(uuid)
+        if value is None:
+            raise KeyError("No file can be found for this uuid", uuid)
         return value
 
     def __setitem__(self, uuid, content):
@@ -137,7 +138,7 @@ class RepositoryService(Service):
 
 repository = RepositoryService()
 
-_REPOSITORY_TRANSACTION = 'abilian_repository_transactions'
+_REPOSITORY_TRANSACTION = "abilian_repository_transactions"
 
 
 class SessionRepositoryState(ServiceState):
@@ -156,7 +157,7 @@ class SessionRepositoryState(ServiceState):
     def transactions(self, value):
         top = _app_ctx_stack.top
         if top is None:
-            raise RuntimeError('working outside of application context')
+            raise RuntimeError("working outside of application context")
 
         setattr(top, _REPOSITORY_TRANSACTION, value)
 
@@ -257,7 +258,8 @@ class SessionRepositoryService(Service):
 
     All content is stored using the main :class:`RepositoryService`.
     """
-    name = 'session_repository'
+
+    name = "session_repository"
     AppStateClass = SessionRepositoryState
 
     def __init__(self, *args, **kwargs):
@@ -267,7 +269,7 @@ class SessionRepositoryService(Service):
     def init_app(self, app):
         Service.init_app(self, app)
 
-        path = Path(app.instance_path, 'tmp', 'files_transactions')
+        path = Path(app.instance_path, "tmp", "files_transactions")
         if not path.exists():
             path.mkdir(0o775, parents=True)
 
@@ -327,7 +329,7 @@ class SessionRepositoryService(Service):
 
         return val
 
-    def set(self, session, uuid, content, encoding='utf-8'):
+    def set(self, session, uuid, content, encoding="utf-8"):
         session = self._session_for(session)
         transaction = self.app_state.get_transaction(session)
         transaction.set(uuid, content, encoding)
@@ -368,7 +370,6 @@ session_repository = SessionRepositoryService()
 
 
 class RepositoryTransaction(object):
-
     def __init__(self, root_path, parent=None):
         self.path = root_path / str(uuid1())
         # if parent is not None and parent.cleared:
@@ -435,7 +436,7 @@ class RepositoryTransaction(object):
 
         for uuid in self._set:
             content = self.path / str(uuid)
-            repository.set(uuid, content.open('rb'))
+            repository.set(uuid, content.open("rb"))
 
     def _commit_parent(self):
         p = self._parent
@@ -467,19 +468,19 @@ class RepositoryTransaction(object):
         # type: (UUID) -> None
         self._add_to(uuid, self._deleted, self._set)
 
-    def set(self, uuid, content, encoding='utf-8'):
-        # type: (UUID, Any, Text) -> None
+    def set(self, uuid, content, encoding="utf-8"):
+        # type: (UUID, Any, Optional[Text]) -> None
         self.begin()
         self._add_to(uuid, self._set, self._deleted)
 
-        if hasattr(content, 'read'):
+        if hasattr(content, "read"):
             content = content.read()
 
         if isinstance(content, bytes):
-            mode = 'wb'
+            mode = "wb"
             encoding = None
         else:
-            mode = 'wt'
+            mode = "wt"
 
         dest = self.path / str(uuid)
         with dest.open(mode, encoding=encoding) as f:
