@@ -21,26 +21,27 @@ from abilian.core.singleton import UniqueName, UniqueNameType
 from abilian.i18n import _l
 
 __all__ = [
-    'RoleAssignment',
-    'PermissionAssignment',
-    'SecurityAudit',
-    'InheritSecurity',
-    'Permission',
-    'MANAGE',
-    'READ',
-    'WRITE',
-    'CREATE',
-    'DELETE',
-    'Role',
-    'Anonymous',
-    'Authenticated',
-    'Admin',
-    'Manager',
-    'Creator',
-    'Owner',
-    'Reader',
-    'Writer',
-    'RoleType',
+    "RoleAssignment",
+    "PermissionAssignment",
+    "SecurityAudit",
+    "InheritSecurity",
+    "Permission",
+    "MANAGE",
+    "READ",
+    "WRITE",
+    "CREATE",
+    "DELETE",
+    "PERMISSIONS_ATTR",
+    "Role",
+    "Anonymous",
+    "Authenticated",
+    "Admin",
+    "Manager",
+    "Creator",
+    "Owner",
+    "Reader",
+    "Writer",
+    "RoleType",
 ]
 
 
@@ -51,12 +52,13 @@ class Permission(UniqueName):
 
     Permission instances are unique by name.
     """
-    __slots__ = ('label',)
+
+    __slots__ = ("label",)
 
     def __init__(self, name, label=None, assignable=True):
         UniqueName.__init__(self, name)
         if label is None:
-            label = 'permission_' + text_type(name)
+            label = "permission_" + text_type(name)
         if isinstance(label, text_type):
             label = _l(label)
         self.label = label
@@ -73,6 +75,7 @@ class PermissionType(UniqueNameType):
 
     Usage:: RoleType()
     """
+
     Type = Permission
 
 
@@ -85,12 +88,13 @@ class Role(UniqueName):
     Non-assignable roles are roles automatically given depending on context (ex:
     Anonymous/Authenticated).
     """
-    __slots__ = ('label', 'assignable')
+
+    __slots__ = ("label", "assignable")
 
     def __init__(self, name, label=None, assignable=True):
         UniqueName.__init__(self, name)
         if label is None:
-            label = 'role_' + text_type(name)
+            label = "role_" + text_type(name)
         if isinstance(label, text_type):
             label = _l(label)
         self.label = label
@@ -100,11 +104,7 @@ class Role(UniqueName):
         return text_type(self.name)
 
     def __repr__(self):
-        return "{}({}, {})".format(
-            self.__class__.__name__,
-            self.name,
-            self.label,
-        )
+        return "{}({}, {})".format(self.__class__.__name__, self.name, self.label)
 
     def __lt__(self, other):
         return text_type(self.label).__lt__(text_type(other.label))
@@ -119,36 +119,33 @@ class RoleType(UniqueNameType):
 
     Usage:: RoleType()
     """
+
     Type = Role
 
 
 #: marker for role assigned to 'Anonymous'
-Anonymous = Role('anonymous', _l('role_anonymous'), assignable=False)
+Anonymous = Role("anonymous", _l("role_anonymous"), assignable=False)
 
 #: marker for role assigned to 'Authenticated'
-Authenticated = Role(
-    'authenticated',
-    _l('role_authenticated'),
-    assignable=False,
-)
+Authenticated = Role("authenticated", _l("role_authenticated"), assignable=False)
 
 #: marker for `admin` role
-Admin = Role('admin', _l('role_administrator'))
+Admin = Role("admin", _l("role_administrator"))
 
 #: marker for `manager` role
-Manager = Role('manager', _l('role_manager'), assignable=False)
+Manager = Role("manager", _l("role_manager"), assignable=False)
 
-Creator = Role('creator', assignable=False)
-Owner = Role('owner', assignable=False)
-Reader = Role('reader', assignable=False)
-Writer = Role('writer', assignable=False)
+Creator = Role("creator", assignable=False)
+Owner = Role("owner", assignable=False)
+Reader = Role("reader", assignable=False)
+Writer = Role("writer", assignable=False)
 
 # Permissions
-READ = Permission('read')
-WRITE = Permission('write')
-MANAGE = Permission('manage')
-CREATE = Permission('create')
-DELETE = Permission('delete')
+READ = Permission("read")
+WRITE = Permission("write")
+MANAGE = Permission("manage")
+CREATE = Permission("create")
+DELETE = Permission("delete")
 
 
 class RoleAssignment(db.Model):
@@ -167,44 +164,32 @@ class RoleAssignment(db.Model):
         ),
         #
         UniqueConstraint(
-            'anonymous',
-            'user_id',
-            'group_id',
-            'role',
-            'object_id',
-            name='assignment_mapped_role_unique',
+            "anonymous",
+            "user_id",
+            "group_id",
+            "role",
+            "object_id",
+            name="assignment_mapped_role_unique",
         ),
     )
 
     id = Column(Integer, primary_key=True, autoincrement=True, nullable=False)
     role = Column(RoleType, index=True, nullable=False)
     anonymous = Column(
-        'anonymous',
+        "anonymous",
         Boolean,
         index=True,
         nullable=True,
         default=False,
         server_default=sql.false(),
     )
-    user_id = Column(
-        Integer,
-        ForeignKey('user.id', ondelete='CASCADE'),
-        index=True,
-    )
-    user = relationship(User, lazy='joined')
-    group_id = Column(
-        Integer,
-        ForeignKey('group.id', ondelete='CASCADE'),
-        index=True,
-    )
-    group = relationship(Group, lazy='joined')
+    user_id = Column(Integer, ForeignKey("user.id", ondelete="CASCADE"), index=True)
+    user = relationship(User, lazy="joined")
+    group_id = Column(Integer, ForeignKey("group.id", ondelete="CASCADE"), index=True)
+    group = relationship(Group, lazy="joined")
 
-    object_id = Column(
-        Integer,
-        ForeignKey(Entity.id, ondelete='CASCADE'),
-        index=True,
-    )
-    object = relationship(Entity, lazy='select')
+    object_id = Column(Integer, ForeignKey(Entity.id, ondelete="CASCADE"), index=True)
+    object = relationship(Entity, lazy="select")
 
 
 # On postgres the UniqueConstraint will not be effective because at least 1
@@ -225,62 +210,70 @@ def _postgres_indexes():
     group_id = RoleAssignment.group_id
     obj = RoleAssignment.object_id
     anonymous = RoleAssignment.anonymous
-    name = 'roleassignment_idx_{}_unique'.format
-    engines = ('postgresql',)
+    name = "roleassignment_idx_{}_unique".format
+    engines = ("postgresql",)
     indexes = [
         Index(
-            name('user_role'),
+            name("user_role"),
             user_id,
             role,
             unique=True,
-            postgresql_where=((anonymous == False) & (group_id == None) &
-                              (obj == None)),
+            postgresql_where=(
+                (anonymous == False) & (group_id == None) & (obj == None)
+            ),
         ),
         Index(
-            name('group_role'),
+            name("group_role"),
             group_id,
             role,
             unique=True,
-            postgresql_where=((anonymous == False) & (user_id == None) &
-                              (obj == None)),
+            postgresql_where=((anonymous == False) & (user_id == None) & (obj == None)),
         ),
         Index(
-            name('anonymous_role'),
+            name("anonymous_role"),
             role,
             unique=True,
-            postgresql_where=((anonymous == True) & (user_id == None) &
-                              (group_id == None) & (obj == None)),
+            postgresql_where=(
+                (anonymous == True)
+                & (user_id == None)
+                & (group_id == None)
+                & (obj == None)
+            ),
         ),
         Index(
-            name('user_role_object'),
+            name("user_role_object"),
             user_id,
             role,
             obj,
             unique=True,
-            postgresql_where=((anonymous == False) & (group_id == None) &
-                              (obj != None)),
+            postgresql_where=(
+                (anonymous == False) & (group_id == None) & (obj != None)
+            ),
         ),
         Index(
-            name('group_role_object'),
+            name("group_role_object"),
             group_id,
             role,
             obj,
             unique=True,
-            postgresql_where=((anonymous == False) & (user_id == None) &
-                              (obj != None)),
+            postgresql_where=((anonymous == False) & (user_id == None) & (obj != None)),
         ),
         Index(
-            name('anonymous_role_object'),
+            name("anonymous_role_object"),
             role,
             obj,
             unique=True,
-            postgresql_where=((anonymous == True) & (user_id == None) &
-                              (group_id == None) & (obj != None)),
+            postgresql_where=(
+                (anonymous == True)
+                & (user_id == None)
+                & (group_id == None)
+                & (obj != None)
+            ),
         ),
     ]
 
     for idx in indexes:
-        idx.info['engines'] = engines
+        idx.info["engines"] = engines
 
     return indexes
 
@@ -288,37 +281,29 @@ def _postgres_indexes():
 _postgres_indexes()
 del _postgres_indexes
 
-PERMISSIONS_ATTR = '__permissions__'
+PERMISSIONS_ATTR = "__permissions__"
 
 
 class PermissionAssignment(db.Model):
-    __tablename__ = 'permission_assignment'
+    __tablename__ = "permission_assignment"
     __table_args__ = (
-        UniqueConstraint(
-            'permission',
-            'role',
-            'object_id',
-            name='assignments_unique',
-        ),
+        UniqueConstraint("permission", "role", "object_id", name="assignments_unique"),
     )
 
     id = Column(Integer, primary_key=True, autoincrement=True, nullable=False)
     permission = Column(PermissionType, index=True, nullable=False)
     role = Column(RoleType, index=True, nullable=False)
     object_id = Column(
-        Integer,
-        ForeignKey(Entity.id, ondelete='CASCADE'),
-        index=True,
-        nullable=True,
+        Integer, ForeignKey(Entity.id, ondelete="CASCADE"), index=True, nullable=True
     )
     object = relationship(
         Entity,
-        lazy='select',
+        lazy="select",
         backref=backref(
             PERMISSIONS_ATTR,
-            lazy='select',
+            lazy="select",
             collection_class=set,
-            cascade='all, delete-orphan',
+            cascade="all, delete-orphan",
             passive_deletes=True,
         ),
     )
@@ -331,8 +316,9 @@ class PermissionAssignment(db.Model):
             return False
 
         return (
-            self.permission == other.permission and
-            self.role == other.role and self.object == other.object
+            self.permission == other.permission
+            and self.role == other.role
+            and self.object == other.object
         )
 
     def __neq__(self, other):
@@ -341,30 +327,32 @@ class PermissionAssignment(db.Model):
     def __repr__(self):
         class_ = self.__class__
         classname = class_.__name__
-        return ('<{cls} instance at 0x{id:x} '
-                'permission={self.permission.name!r} '
-                'role={self.role.name!r} object={self.object!r}>'
-                ''.format(cls=classname, id=id(self), self=self))
+        return (
+            "<{cls} instance at 0x{id:x} "
+            "permission={self.permission.name!r} "
+            "role={self.role.name!r} object={self.object!r}>"
+            "".format(cls=classname, id=id(self), self=self)
+        )
 
 
 def _postgres_indexes():
     # we need a unique index for when object_id is NULL; when it's not the
     # uniqueconstraint will just work.
     PA = PermissionAssignment
-    name = 'ix_permission_assignment_{}_unique'.format
-    engines = ('postgresql',)
+    name = "ix_permission_assignment_{}_unique".format
+    engines = ("postgresql",)
     indexes = [
         Index(
-            name('permission_role_global'),
+            name("permission_role_global"),
             PA.permission,
             PA.role,
             unique=True,
             postgresql_where=(PA.object_id == None),
-        ),
+        )
     ]
 
     for idx in indexes:
-        idx.info['engines'] = engines
+        idx.info["engines"] = engines
 
     return indexes
 
@@ -375,10 +363,11 @@ del _postgres_indexes
 
 class SecurityAudit(db.Model):
     """Logs changes on security."""
-    GRANT = 'GRANT'
-    REVOKE = 'REVOKE'
-    SET_INHERIT = 'SET_INHERIT'
-    UNSET_INHERIT = 'UNSET_INHERIT'
+
+    GRANT = "GRANT"
+    REVOKE = "REVOKE"
+    SET_INHERIT = "SET_INHERIT"
+    UNSET_INHERIT = "UNSET_INHERIT"
 
     __tablename__ = "securityaudit"
     __table_args__ = (
@@ -409,26 +398,20 @@ class SecurityAudit(db.Model):
     id = Column(Integer, primary_key=True)
     happened_at = Column(DateTime, default=datetime.utcnow, index=True)
     op = Column(
-        Enum(
-            GRANT,
-            REVOKE,
-            SET_INHERIT,
-            UNSET_INHERIT,
-            name='securityaudit_enum_op',
-        ),
+        Enum(GRANT, REVOKE, SET_INHERIT, UNSET_INHERIT, name="securityaudit_enum_op")
     )
     role = Column(RoleType)
 
     manager_id = Column(Integer, ForeignKey(User.id))
     manager = relationship(User, foreign_keys=manager_id)
-    anonymous = Column('anonymous', Boolean, nullable=True, default=False)
-    user_id = Column(Integer, ForeignKey('user.id'))
-    user = relationship("User", lazy='joined', foreign_keys=user_id)
-    group_id = Column(Integer, ForeignKey('group.id'))
-    group = relationship("Group", lazy='joined')
+    anonymous = Column("anonymous", Boolean, nullable=True, default=False)
+    user_id = Column(Integer, ForeignKey("user.id"))
+    user = relationship("User", lazy="joined", foreign_keys=user_id)
+    group_id = Column(Integer, ForeignKey("group.id"))
+    group = relationship("Group", lazy="joined")
 
     _fk_object_id = Column(Integer, ForeignKey(Entity.id, ondelete="SET NULL"))
-    object = relationship(Entity, lazy='select')
+    object = relationship(Entity, lazy="select")
 
     object_id = Column(Integer)
     object_type = Column(String(1000))
@@ -437,9 +420,7 @@ class SecurityAudit(db.Model):
 
 class InheritSecurity(object):
     """Mixin for objects with a parent relation and security inheritance."""
+
     inherit_security = Column(
-        Boolean,
-        default=True,
-        nullable=False,
-        info={'auditable': False},
+        Boolean, default=True, nullable=False, info={"auditable": False}
     )
