@@ -1,8 +1,7 @@
 # coding=utf-8
 """Elements to build test cases for an :class:`abilian.app.Application`"""
-from __future__ import absolute_import, print_function, division, \
-    unicode_literals
+from __future__ import absolute_import, print_function, division, unicode_literals
 
 from .base import BaseTestCase, TestConfig
 
-__all__ = ('BaseTestCase', 'TestConfig')
+__all__ = ("BaseTestCase", "TestConfig")
