@@ -5,4 +5,4 @@ from __future__ import absolute_import, division, print_function
 from .extension import Admin
 from .panel import AdminPanel
 
-__all__ = ['Admin', 'AdminPanel']
+__all__ = ["Admin", "AdminPanel"]
