@@ -8,7 +8,7 @@ from datetime import datetime, timedelta
 import pandas as pd
 import six
 import sqlalchemy as sa
-from flask import current_app, render_template
+from flask import render_template
 from numpy import sum as numpysum
 
 from abilian.core.extensions import db
@@ -21,43 +21,42 @@ from ..panel import AdminPanel
 
 
 class DashboardPanel(AdminPanel):
-    id = 'dashboard'
-    path = ''
-    label = _l('Dashboard')
-    icon = 'eye-open'
+    id = "dashboard"
+    path = ""
+    label = _l("Dashboard")
+    icon = "eye-open"
 
     def get(self):
-        login_entries = LoginSession.query \
-            .order_by(LoginSession.started_at.asc()) \
-            .all()
+        login_entries = LoginSession.query.order_by(LoginSession.started_at.asc()).all()
         # .options(sa.orm.joinedload(LoginSession.user))
         daily, weekly, monthly = uniquelogins(login_entries)
         new_logins, total_users = newlogins(login_entries)
 
         stats = {
-            'today': stats_since(timedelta(days=1)),
-            'this_week': stats_since(timedelta(days=7)),
-            'this_month': stats_since(timedelta(days=30)),
+            "today": stats_since(timedelta(days=1)),
+            "this_week": stats_since(timedelta(days=7)),
+            "this_month": stats_since(timedelta(days=30)),
         }
 
         # let's format the data into NVD3 datastructures
         connections = [
-            {'key': _('Daily'), 'color': '#7777ff', 'values': daily},
+            {"key": _("Daily"), "color": "#7777ff", "values": daily},
             {
-                'key': _('Weekly'), 'color': '#2ca02c',
-                'values': weekly, 'disabled': True,
+                "key": _("Weekly"),
+                "color": "#2ca02c",
+                "values": weekly,
+                "disabled": True,
             },
             {
-                'key': _('Monthly'), 'color': '#ff7f0e',
-                'values': monthly, 'disabled': True,
+                "key": _("Monthly"),
+                "color": "#ff7f0e",
+                "values": monthly,
+                "disabled": True,
             },
         ]
         new_logins = [
-            {
-                'key': _('New'), 'color': '#ff7f0e',
-                "bar": True, 'values': new_logins,
-            },
-            {'key': _('Total'), 'color': '#2ca02c', 'values': total_users},
+            {"key": _("New"), "color": "#ff7f0e", "bar": True, "values": new_logins},
+            {"key": _("Total"), "color": "#2ca02c", "values": total_users},
         ]
 
         return render_template(
@@ -72,33 +71,37 @@ def stats_since(dt):
     new_members = new_documents = new_messages = 0
     after_date = datetime.utcnow() - dt
     session = db.session()
-    counts_per_type = session \
-        .query(
-            AuditEntry.entity_type.label('type'),
-            sa.func.count(AuditEntry.entity_type).label('count'),
-        ) \
-        .group_by(AuditEntry.entity_type) \
-        .filter(AuditEntry.happened_at > after_date) \
-        .filter(AuditEntry.type == CREATION) \
+    counts_per_type = (
+        session.query(
+            AuditEntry.entity_type.label("type"),
+            sa.func.count(AuditEntry.entity_type).label("count"),
+        )
+        .group_by(AuditEntry.entity_type)
+        .filter(AuditEntry.happened_at > after_date)
+        .filter(AuditEntry.type == CREATION)
         .all()
+    )
 
     for entity_type, count in counts_per_type:
-        entity_class = entity_type.split('.')[-1]
-        if entity_class == 'User':
+        entity_class = entity_type.split(".")[-1]
+        if entity_class == "User":
             new_members = count
-        elif entity_class == 'Document':
+        elif entity_class == "Document":
             new_documents = count
-        elif entity_class == 'Message':
+        elif entity_class == "Message":
             new_messages = count
 
-    active_users = session.query(sa.func.count(User.id)) \
-        .filter(User.last_active > after_date).scalar()
+    active_users = (
+        session.query(sa.func.count(User.id))
+        .filter(User.last_active > after_date)
+        .scalar()
+    )
 
     return {
-        'new_members': new_members,
-        'active_users': active_users,
-        'new_documents': new_documents,
-        'new_messages': new_messages,
+        "new_members": new_members,
+        "active_users": active_users,
+        "new_documents": new_documents,
+        "new_messages": new_messages,
     }
 
 
@@ -139,9 +142,9 @@ def newlogins(sessions):
     for date in sorted(dates.keys()):
         # print u"{} : {}".format(date, len(dates[date]))
         date_epoch = unix_time_millis(datetime.strptime(date, "%Y/%m/%d"))
-        data.append({'x': date_epoch, 'y': len(dates[date])})
+        data.append({"x": date_epoch, "y": len(dates[date])})
         previous += len(dates[date])
-        total.append({'x': date_epoch, 'y': previous})
+        total.append({"x": date_epoch, "y": previous})
 
     return data, total
 
@@ -174,7 +177,7 @@ def uniquelogins(sessions):
     for date in sorted(dates.keys()):
         # print u"{} : {}".format(date, len(dates[date]))
         date_epoch = unix_time_millis(datetime.strptime(date, "%Y/%m/%d"))
-        daily.append({'x': date_epoch, 'y': len(dates[date])})
+        daily.append({"x": date_epoch, "y": len(dates[date])})
 
     # first_day = data[0]['x']
     # last_day = data[-1]['x']
@@ -186,12 +189,8 @@ def uniquelogins(sessions):
     daily_serie = daily_serie.apply(lambda x: len(x))
 
     # GroupBy Week/month, Thanks Panda
-    weekly_serie = daily_serie \
-        .groupby(pd.TimeGrouper(freq='W')) \
-        .aggregate(numpysum)
-    monthly_serie = daily_serie \
-        .groupby(pd.TimeGrouper(freq='M')) \
-        .aggregate(numpysum)
+    weekly_serie = daily_serie.groupby(pd.TimeGrouper(freq="W")).aggregate(numpysum)
+    monthly_serie = daily_serie.groupby(pd.TimeGrouper(freq="M")).aggregate(numpysum)
 
     for date, value in six.iteritems(weekly_serie):
         try:
@@ -199,7 +198,7 @@ def uniquelogins(sessions):
         except ValueError:
             continue
         date_epoch = unix_time_millis(date)
-        weekly.append({'x': date_epoch, 'y': value})
+        weekly.append({"x": date_epoch, "y": value})
 
     for date, value in six.iteritems(monthly_serie):
         try:
@@ -207,6 +206,6 @@ def uniquelogins(sessions):
         except ValueError:
             continue
         date_epoch = unix_time_millis(date)
-        monthly.append({'x': date_epoch, 'y': value})
+        monthly.append({"x": date_epoch, "y": value})
 
     return daily, weekly, monthly
