@@ -11,22 +11,17 @@ from flask_login import login_user
 
 from abilian.web.preferences.user import UserPreferencesForm
 
-AVATAR_COLORMAP = Path(__file__).parent / 'avatar-colormap.png'
+AVATAR_COLORMAP = Path(__file__).parent / "avatar-colormap.png"
 
 
 def test_form_photo(app, db):
     user = app.create_root_user()
-    url = url_for('preferences.user')
-    uploads = app.extensions['uploads']
-    with AVATAR_COLORMAP.open('rb') as f:
-        handle = uploads.add_file(
-            user,
-            f,
-            filename='avatar.png',
-            mimetype='image/png',
-        )
+    url = url_for("preferences.user")
+    uploads = app.extensions["uploads"]
+    with AVATAR_COLORMAP.open("rb") as f:
+        handle = uploads.add_file(user, f, filename="avatar.png", mimetype="image/png")
 
-    kwargs = dict(method='POST', data={'photo': handle})
+    kwargs = dict(method="POST", data={"photo": handle})
 
     with app.test_request_context(url, **kwargs):
         login_user(user)
@@ -34,11 +29,11 @@ def test_form_photo(app, db):
         form.validate()
         assert form.photo.data is not None
 
-        if hasattr(form.photo.data, 'read'):
+        if hasattr(form.photo.data, "read"):
             data = form.photo.data.read()
         else:
             data = form.photo.data
 
-        img_type = imghdr.what('ignored', data)
+        img_type = imghdr.what("ignored", data)
         # FIXME: should be 'png' but is 'jpeg' on Python 2
-        assert img_type in ('png', 'jpeg')
+        assert img_type in ("png", "jpeg")
