@@ -1,9 +1,6 @@
 /* datatable: advanced search */
 
-(function(factory) {
-  "use strict";
-  require(["AbilianNS", "jquery", "jquery.dataTables"], factory);
-})(function(Abilian, $) {
+require(["AbilianNS", "jquery", "jquery.dataTables"], function(Abilian, $) {
   "use strict";
 
   function defaultDatatableConfig() {
@@ -45,7 +42,7 @@
     }
 
     var length = unset.length;
-    if (unset.length != val.length) {
+    if (unset.length !== val.length) {
       return true;
     }
 
@@ -450,7 +447,7 @@
       },
       load: function(vals) {
         this.$elements.find("input").each(function() {
-          this.checked = this.value == vals[0];
+          this.checked = this.value === vals[0];
         });
       },
     };
@@ -563,7 +560,6 @@
     }
 
     function getVal() {
-      /* jshint validthis: true */
       var val = this.$select.data("select2").val();
       if (!this.multiple && !val.length) {
         val = [];
@@ -628,7 +624,6 @@
     }
 
     function getVal() {
-      /* jshint validthis: true */
       var val = this.$select.data("select2").val();
       if (!this.multiple && !val.length) {
         val = [];
@@ -637,7 +632,6 @@
     }
 
     function saveVal() {
-      /* jshint validthis: true */
       var data = this.$select.data("select2").data();
 
       if (data) {
@@ -733,7 +727,6 @@
        get value to fill the  /GET : response with the attribute
        return: list(select:id, radio:value)
        */
-      /* jshint validthis: true */
       var radioValue = this.$elements.find("input:checked").val();
       var select2Value = this.$select.select2("val");
 
@@ -806,7 +799,6 @@
     }
 
     function getVal() {
-      /* jshint validthis: true */
       if (this.$input.get(0).checked) {
         return [this.$select.select2("val") || this.$input.val()];
       }
@@ -963,7 +955,6 @@
       },
 
       hasValueSet: function() {
-        /* jshint camelcase: false */
         return getValues(this).selected_filters.length > 0;
       },
     };
@@ -988,7 +979,9 @@
       sFeature: "AdvancedSearchFilters",
     });
   } else {
-    throw "Warning: AdvancedSearchFilters requires DataTables 1.7 or greater - www.datatables.net/download";
+    throw new Error(
+      "Warning: AdvancedSearchFilters requires DataTables 1.7 or greater - www.datatables.net/download"
+    );
   }
 
   /*
