@@ -24,16 +24,13 @@ logger = logging.getLogger(__name__)
 CHUNK_SIZE = 64 * 1024
 
 DEFAULT_CONFIG = {
-    'USER_QUOTA': 100 * 1024**2,  # max 100 Mb for all current files
-    'USER_MAX_FILES': 1000,  # max number of files per user
-    'DELETE_STALLED_AFTER': 60 * 60 * 24,  # delete files remaining after 1 day
+    "USER_QUOTA": 100 * 1024 ** 2,  # max 100 Mb for all current files
+    "USER_MAX_FILES": 1000,  # max number of files per user
+    "DELETE_STALLED_AFTER": 60 * 60 * 24,  # delete files remaining after 1 day
 }
 
-CLEANUP_SCHEDULE_ID = __name__ + '.periodic_clean_upload_directory'
-DEFAULT_CLEANUP_SCHEDULE = {
-    'task': CLEANUP_SCHEDULE_ID,
-    'schedule': timedelta(hours=1),
-}
+CLEANUP_SCHEDULE_ID = __name__ + ".periodic_clean_upload_directory"
+DEFAULT_CLEANUP_SCHEDULE = {"task": CLEANUP_SCHEDULE_ID, "schedule": timedelta(hours=1)}
 
 
 def is_valid_handle(handle):
@@ -57,22 +54,22 @@ class FileUploadsExtension(object):
     """
 
     def __init__(self, app):
-        app.extensions['uploads'] = self
-        app.add_template_global(self, 'uploads')
+        app.extensions["uploads"] = self
+        app.add_template_global(self, "uploads")
         app.register_blueprint(blueprint)
         signals.register_js_api.connect(self._do_register_js_api)
 
         self.config = {}
         self.config.update(DEFAULT_CONFIG)
-        self.config.update(app.config.get('FILE_UPLOADS', {}))
-        app.config['FILE_UPLOADS'] = self.config
+        self.config.update(app.config.get("FILE_UPLOADS", {}))
+        app.config["FILE_UPLOADS"] = self.config
 
         # celery schedule
-        CELERYBEAT_SCHEDULE = app.config.setdefault('CELERYBEAT_SCHEDULE', {})
+        CELERYBEAT_SCHEDULE = app.config.setdefault("CELERYBEAT_SCHEDULE", {})
         if CLEANUP_SCHEDULE_ID not in CELERYBEAT_SCHEDULE:
             CELERYBEAT_SCHEDULE[CLEANUP_SCHEDULE_ID] = DEFAULT_CLEANUP_SCHEDULE
 
-        path = self.UPLOAD_DIR = app.DATA_DIR / 'uploads'
+        path = self.UPLOAD_DIR = app.DATA_DIR / "uploads"
         if not path.exists():
             path.mkdir(mode=0o775, parents=True)
 
@@ -80,12 +77,12 @@ class FileUploadsExtension(object):
 
     def _do_register_js_api(self, sender):
         app = sender
-        js_api = app.js_api.setdefault('upload', {})
-        js_api['newFileUrl'] = url_for('uploads.new_file')
+        js_api = app.js_api.setdefault("upload", {})
+        js_api["newFileUrl"] = url_for("uploads.new_file")
 
     def user_dir(self, user):
         if isinstance(user, AnonymousUserMixin):
-            user_id = 'anonymous'
+            user_id = "anonymous"
         else:
             user_id = text_type(user.id)
         return self.UPLOAD_DIR / user_id
@@ -102,16 +99,16 @@ class FileUploadsExtension(object):
         handle = str(uuid1())
         file_path = user_dir / handle
 
-        with file_path.open('wb') as out:
-            for chunk in iter(lambda: file_obj.read(CHUNK_SIZE), b''):
+        with file_path.open("wb") as out:
+            for chunk in iter(lambda: file_obj.read(CHUNK_SIZE), b""):
                 out.write(chunk)
 
         if metadata:
-            meta_file = user_dir / '{}.metadata'.format(handle)
-            with meta_file.open('wb') as out:
+            meta_file = user_dir / "{}.metadata".format(handle)
+            with meta_file.open("wb") as out:
                 metadata_json = json.dumps(metadata, skipkeys=True)
                 if PY3:
-                    metadata_json = metadata_json.encode('ascii')
+                    metadata_json = metadata_json.encode("ascii")
                 out.write(metadata_json)
 
         return handle
@@ -141,7 +138,7 @@ class FileUploadsExtension(object):
         if content is None:
             return None
 
-        metafile = content.parent / '{}.metadata'.format(handle)
+        metafile = content.parent / "{}.metadata".format(handle)
         if not metafile.exists():
             return None
 
@@ -153,7 +150,7 @@ class FileUploadsExtension(object):
             return {}
 
         try:
-            with metafile.open('rb') as in_:
+            with metafile.open("rb") as in_:
                 meta = json.load(in_)
         except BaseException:
             meta = {}
@@ -161,17 +158,14 @@ class FileUploadsExtension(object):
         return meta
 
     def remove_file(self, user, handle):
-        paths = (
-            self.get_file(user, handle),
-            self.get_metadata_file(user, handle),
-        )
+        paths = (self.get_file(user, handle), self.get_metadata_file(user, handle))
 
         for file_path in paths:
             if file_path is not None:
                 try:
                     file_path.unlink()
                 except BaseException:
-                    logger.exception('Error during remove file')
+                    logger.exception("Error during remove file")
 
     def clear_stalled_files(self):
         """Scan upload directory and delete stalled files.
@@ -180,22 +174,18 @@ class FileUploadsExtension(object):
         `DELETE_STALLED_AFTER` seconds ago.
         """
         # FIXME: put lock in directory?
-        CLEAR_AFTER = self.config['DELETE_STALLED_AFTER']
+        CLEAR_AFTER = self.config["DELETE_STALLED_AFTER"]
         minimum_age = time.time() - CLEAR_AFTER
 
         for user_dir in self.UPLOAD_DIR.iterdir():
             if not user_dir.is_dir():
-                logger.error(
-                    'Found non-directory in upload dir: %r',
-                    bytes(user_dir),
-                )
+                logger.error("Found non-directory in upload dir: %r", bytes(user_dir))
                 continue
 
             for content in user_dir.iterdir():
                 if not content.is_file():
                     logger.error(
-                        'Found non-file in user upload dir: %r',
-                        bytes(content),
+                        "Found non-file in user upload dir: %r", bytes(content)
                     )
                     continue
 
@@ -212,5 +202,5 @@ def periodic_clean_upload_directory():
     :data:`DEFAULT_CLEANUP_SCHEDULE`. `CELERYBEAT_SCHEDULE` key is
     :data:`CLEANUP_SCHEDULE_ID`.
     """
-    uploads = current_app.extensions['uploads']
+    uploads = current_app.extensions["uploads"]
     uploads.clear_stalled_files()
