@@ -39,7 +39,7 @@ def url_for(obj, **kw):
         elif hasattr(obj, "url"):
             return obj.url
 
-    raise BuildError(repr(obj), kw, 'GET')
+    raise BuildError(repr(obj), kw, "GET")
 
 
 def get_object_or_404(cls, *args):
@@ -62,8 +62,7 @@ def send_file_from_directory(filename, directory, app=None):
     if app is None:
         app = current_app
     cache_timeout = app.get_send_file_max_age(filename)
-    return send_from_directory(
-        directory, filename, cache_timeout=cache_timeout)
+    return send_from_directory(directory, filename, cache_timeout=cache_timeout)
 
 
 def capture_stream_errors(logger, msg):
@@ -79,14 +78,11 @@ def capture_stream_errors(logger, msg):
         logger = logging.getLogger(logger)
 
     def decorator(fun):
-
         @stream_with_context
         def wrapper(*args, **kwargs):
             # this is for developpers convenience. The debugger middleware doesn't
             # work when using streamed responses.
-            should_pdb = current_app.debug and session.get(
-                'pdb_streamed_responses',
-            )
+            should_pdb = current_app.debug and session.get("pdb_streamed_responses")
             try:
                 generator = fun(*args, **kwargs)
                 for chunk in generator:
